@@ -52,8 +52,8 @@ def zipfiles(filepaths):
     try:
         noext_archivename = osp.splitext(DataZipView.archive_name)[0]
         with closing(ZipFile(archive_filepath, "w", ZIP_DEFLATED, True)) as zip:
-            for filename, subj, filepath in filepaths:
-                zip.write(filepath, '%s/%s/%s' % (noext_archivename, subj, filename))
+            for filename, subj, _fileobj in filepaths:
+                zip.writestr('%s/%s/%s' % (noext_archivename, subj, filename), _fileobj.read())
         fileobj = os.fdopen(fd)
         fileobj.seek(0)
         return fileobj, archive_filepath
@@ -82,19 +82,12 @@ class DataZipView(EntityView):
             return
         filepaths = set()
         for entity in self.cw_rset.entities():
-            if entity.__regid__ == 'GenomicMeasure':
-                for ext in ('.bim', '.bed', '.fam'):
-                    filepath = osp.splitext(osp.basename(entity.filepath))[0] + ext
-                    full_filepath = osp.splitext(entity.full_filepath)[0] + ext
-                    filepaths.add((filepath, entity.concerns[0].identifier, full_filepath))
-            else:
-                filename = entity.type + '_' + osp.basename(entity.filepath)
-                filename = filename.replace(' ', '_')
-                filepaths.add((filename, entity.concerns[0].identifier, entity.full_filepath))
-            for external_resource in entity.external_resources:
-                filepaths.add((osp.basename(external_resource.filepath),
-                               entity.concerns[0].identifier,
-                               external_resource.full_filepath))
+            for _file in entity.results_files:
+                if _file.__regid__ == 'FileSet':
+                    for _f in _file.file_entries:
+                        filepaths.add(_file.dc_title(), subj, _f)
+                else:
+                        filepaths.add(_file.dc_title(), subj, _file)
         fileobj, archive_filepath = zipfiles(list(filepaths))
         try:
             self.w(fileobj.read())
